@@ -6,10 +6,7 @@ import numpy as np
 
 from openquake.hazardlib import const
 from openquake.hazardlib.gsim.base import GMPE, registry
-from openquake.hazardlib.gsim.campbell_bozorgnia_2014 import (
-    CampbellBozorgnia2014,
-    _get_basin_response_term,
-)
+from openquake.hazardlib.gsim.mgmpe.cb14_basin_term import _get_cb14_basin_term
 
 from esi_shakelib.utils.gmpe_coeffs import get_gmpe_coef_table
 
@@ -36,14 +33,12 @@ class M9BasinTerm(GMPE):
         super().__init__(**kwargs)
         self.gmpe = registry[gmpe_name]()
         self.COEFFS = get_gmpe_coef_table(self.gmpe)
-        self.cb14 = CampbellBozorgnia2014()
         self.set_parameters()
 
     def compute(self, ctx: np.recarray, imts, mean, sig, tau, phi):
         self.gmpe.compute(ctx, imts, mean, sig, tau, phi)
         for m, imt in enumerate(imts):
-            coeffs = self.cb14.COEFFS[imt]
-            fb = _get_basin_response_term(self.SJ, coeffs, ctx.z2pt5)
+            fb = _get_cb14_basin_term(imt, ctx, self.SJ)
             if self.m9:
                 fb_m9 = np.log(2.0)
                 idx = ctx.z2pt5 > 6.0
