@@ -382,8 +382,8 @@ class StationList(object):
                     nresp = int(feature["properties"].get("nresp", -1))
                 except (ValueError, TypeError):
                     nresp = -1
-                if nresp >= 0 and nresp < min_nresp:
-                    continue
+                # if nresp >= 0 and nresp < min_nresp:
+                #     continue
                 flag = feature["properties"]["intensity_flag"]
                 if not flag or flag == "":
                     flag = "0"
@@ -1141,7 +1141,6 @@ class StationList(object):
                         df[this_row[1]][rowidx] = np.sqrt(cval * amp)
                     elif component == "ARITHMETIC_MEAN":
                         df[this_row[1]][rowidx] = (cval + amp) / 2.0
-
         return df, myimts
 
     def _fixOrientations(self):
@@ -1409,8 +1408,8 @@ class StationList(object):
                         nresp = int(attributes["nresp"])
                     else:
                         nresp = -1
-                    if nresp >= 0 and nresp < min_nresp:
-                        continue
+                    # if nresp >= 0 and nresp < min_nresp:
+                    #     continue
                     compdict["mmi"]["amps"]["MMI"] = {
                         "value": float(attributes["intensity"]),
                         "stddev": stddev,
